#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem

ifs = oechem.oemolistream()
if not ifs.open("drugs.oeb"):
    oechem.OEThrow.Fatal("Unable to open file")

# @ <SNIPPET>
mol = oechem.OEMol()
oechem.OEReadMolecule(ifs, mol)
crmsd = oechem.OEConfRMSD(mol)

confiidx = 0
confjidx = 0
minRMSD = float("inf")
confs = list(mol.GetConfs())
for ci in range(len(confs)):
    for cj in range(ci + 1, len(confs)):
        trans = oechem.OETrans()
        dist = crmsd.MinimizeRMSD(confs[ci], confs[cj], trans)
        if dist < minRMSD:
            minRMSD = dist
            confiidx = ci
            confjidx = cj

print('The closest conformers are ', confiidx, ' and ', confjidx, end=" ")
print(' with RMSD = ', minRMSD)
# @ </SNIPPET>
