#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oeszybki


def main(argv=[__name__]):
    szOpts = oeszybki.OEProteinLigandOptOptions()
    opts = oechem.OERefInputAppOptions(szOpts, "OptimizeLigandInDU", oechem.OEFileStringType_Mol3D,
                                       oechem.OEFileStringType_Mol3D, oechem.OEFileStringType_DU, "-du")
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    szOpts.UpdateValues(opts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    rfs = oechem.oeifstream()
    if not rfs.open(opts.GetRefFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetRefFile())

    ofs = oechem.oemolostream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    du = oechem.OEDesignUnit()
    if not oechem.OEReadDesignUnit(rfs, du):
        oechem.OEThrow.Fatal("Failed to read design unit")

    optimizer = oeszybki.OEFixedProteinLigandOptimizer(szOpts)
    optimizer.SetProtein(du, oechem.OEDesignUnitComponents_Protein)

    for mol in ifs.GetOEMols():
        oechem.OEThrow.Info("Title: %s" % mol.GetTitle())
        conf = 0
        for res in optimizer.Optimize(mol):
            conf += 1
            if res.GetReturnCode() == oeszybki.OESzybkiReturnCode_Success:
                oechem.OEThrow.Info("Conformer: %d" % conf)
                initEne = res.GetInitialEnergies()
                oechem.OEThrow.Info("Initial energies:")
                oechem.OEThrow.Info("  Ligand: %0.2f" % initEne.GetLigandEnergy())
                oechem.OEThrow.Info("  Intermolecular: %0.2f" % initEne.GetInterEnergy())
                oechem.OEThrow.Info("  Total: %0.2f" % initEne.GetTotalEnergy())
                finalEne = res.GetFinalEnergies()
                oechem.OEThrow.Info("Final energies:")
                oechem.OEThrow.Info("  Ligand: %0.2f" % finalEne.GetLigandEnergy())
                oechem.OEThrow.Info("  Intermolecular: %0.2f" % finalEne.GetInterEnergy())
                oechem.OEThrow.Info("  Total: %0.2f" % finalEne.GetTotalEnergy())
            else:
                oechem.OEThrow.Warning("Failed: %s" % oeszybki.OEGetSzybkiError(res.GetReturnCode()))
        oechem.OEWriteMolecule(ofs, mol)
    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))
