#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oeszybki


class MyOptions(oechem.OEOptions):
    def __init__(self):
        oechem.OEOptions.__init__(self, "MyOption")
        self._optOpts = oeszybki.OEProteinLigandOptOptions()
        self._flexOpts = oeszybki.OEProteinFlexOptions()
        self.AddOption(self._optOpts)
        self.AddOption(self._flexOpts)
        pass

    def CreateCopy(self):
        return self

    def GetOptOptions(self):
        return self._optOpts

    def GetFlexOptions(self):
        return self._flexOpts


def main(argv=[__name__]):
    myOpts = MyOptions()
    opts = oechem.OESimpleAppOptions(myOpts, "OptimizeDU", oechem.OEFileStringType_DU, oechem.OEFileStringType_DU)
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    optOpts = myOpts.GetOptOptions()
    flexOpts = myOpts.GetFlexOptions()
    optOpts.UpdateValues(opts)
    flexOpts.UpdateValues(opts)

    ifs = oechem.oeifstream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    ofs = oechem.oeofstream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    optimizer = oeszybki.OEFlexProteinLigandOptimizer(optOpts)
    du = oechem.OEDesignUnit()
    while oechem.OEReadDesignUnit(ifs, du):
        oechem.OEThrow.Info("Title: %s" % du.GetTitle())
        res = oeszybki.OEProteinLigandOptResults()
        proteinMask = oechem.OEDesignUnitComponents_Protein
        retCode = optimizer.Optimize(res, du, proteinMask, oechem.OEDesignUnitComponents_Ligand, flexOpts)
        if retCode == oeszybki.OESzybkiReturnCode_Success:
            initEne = res.GetInitialEnergies()
            oechem.OEThrow.Info("Initial energies:")
            oechem.OEThrow.Info("  Ligand: %0.2f" % initEne.GetLigandEnergy())
            oechem.OEThrow.Info("  Flexible Protein: %0.2f" % initEne.GetHostEnergy())
            oechem.OEThrow.Info("  Intermolecular: %0.2f" % initEne.GetInterEnergy())
            oechem.OEThrow.Info("  Total: %0.2f" % initEne.GetTotalEnergy())
            finalEne = res.GetFinalEnergies()
            oechem.OEThrow.Info("Final energies:")
            oechem.OEThrow.Info("  Ligand: %0.2f" % finalEne.GetLigandEnergy())
            oechem.OEThrow.Info("  Flexible Protein: %0.2f" % finalEne.GetHostEnergy())
            oechem.OEThrow.Info("  Intermolecular: %0.2f" % finalEne.GetInterEnergy())
            oechem.OEThrow.Info("  Total: %0.2f" % finalEne.GetTotalEnergy())
            oechem.OEWriteDesignUnit(ofs, du)
        else:
            oechem.OEThrow.Warning("%s: %s" % (du.GetTitle(), oeszybki.OEGetSzybkiError(retCode)))
    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))
